@@ -27,6 +27,10 @@ public enum MyEnum {
 }
 </pre>
  * as an alternative to using {@link JsonValue} annotation.
+ *<p>
+ * Starting with Jackson 2.12 it is also possible to specify {@code namespace}
+ * of property: this property is only used by certain format backends (most
+ * notably XML).
  */
 @Target({ElementType.ANNOTATION_TYPE, ElementType.FIELD, ElementType.METHOD, ElementType.PARAMETER})
 @Retention(RetentionPolicy.RUNTIME)
@@ -61,6 +65,15 @@ public @interface JsonProperty
      */
     String value() default USE_DEFAULT_NAME;
 
+    /**
+     * Optional namespace to use with data formats that support such
+     * concept (specifically XML); if so, used with {@link #value} to
+     * construct fully-qualified name.
+     *
+     * @since 2.12
+     */
+    String namespace() default "";
+
     /**
      * Property that indicates whether a value (which may be explicit
      * null) is expected for property during deserialization or not.
@@ -97,7 +110,7 @@ public @interface JsonProperty
      * Property that may be used to <b>document</b> expected default value
      * for the property: most often used as source information for generating
      * schemas (like JSON Schema or protobuf/thrift schema), or documentation.
-     * It may also be used by Jackson extension modules; core jackson databind
+     * It may also be used by Jackson extension modules; core `jackson-databind`
      * does not have any automated handling beyond simply exposing this
      * value through bean property introspection.
      *<p>
@@ -111,7 +124,7 @@ public @interface JsonProperty
 
     /**
      * Optional property that may be used to change the way visibility of
-     * accessors (getter, field-as-getter) and mutators (contructor parameter,
+     * accessors (getter, field-as-getter) and mutators (constructor parameter,
      * setter, field-as-setter) is determined, either so that otherwise
      * non-visible accessors (like private getters) may be used; or that
      * otherwise visible accessors are ignored.
@@ -147,15 +160,19 @@ public @interface JsonProperty
         AUTO,
 
         /**
-         * Access setting that means that the property may only be read for serialization,
+         * Access setting that means that the property may only be read for serialization
+         * (value accessed via "getter" Method, or read from Field)
          * but not written (set) during deserialization.
+         * Put another way, this would reflect "read-only POJO", in which value contained
+         * may be read but not written/set.
          */
         READ_ONLY,
 
         /**
          * Access setting that means that the property may only be written (set)
-         * for deserialization,
-         * but will not be read (get) on serialization, that is, the value of the property
+         * as part of deserialization (using "setter" method, or assigning to Field,
+         * or passed as Creator argument)
+         * but will not be read (get) for serialization, that is, the value of the property
          * is not included in serialization.
          */
         WRITE_ONLY,
