@@ -55,7 +55,7 @@ public class FormatTest extends TestBase
     }
     
     public void testToString() {
-        assertEquals("JsonFormat.Value(pattern=null,shape=STRING,lenient=null,locale=null,timezone=null,features=EMPTY)",
+        assertEquals("JsonFormat.Value(pattern=,shape=STRING,lenient=null,locale=null,timezone=null,features=EMPTY)",
                 JsonFormat.Value.forShape(JsonFormat.Shape.STRING).toString());
         assertEquals("JsonFormat.Value(pattern=[.],shape=ANY,lenient=null,locale=null,timezone=null,features=EMPTY)",
                 JsonFormat.Value.forPattern("[.]").toString());
@@ -186,6 +186,17 @@ public class FormatTest extends TestBase
         assertFalse(dunno.equals(lenient));
     }
 
+    public void testCaseInsensitiveValues() {
+        JsonFormat.Value empty = JsonFormat.Value.empty();
+        assertNull(empty.getFeature(Feature.ACCEPT_CASE_INSENSITIVE_VALUES));
+
+        JsonFormat.Value insensitive = empty.withFeature(Feature.ACCEPT_CASE_INSENSITIVE_VALUES);
+        assertTrue(insensitive.getFeature(Feature.ACCEPT_CASE_INSENSITIVE_VALUES));
+
+        JsonFormat.Value sensitive = empty.withoutFeature(Feature.ACCEPT_CASE_INSENSITIVE_VALUES);
+        assertFalse(sensitive.getFeature(Feature.ACCEPT_CASE_INSENSITIVE_VALUES));
+    }
+
     public void testShape() {
         assertFalse(JsonFormat.Shape.STRING.isNumeric());
         assertFalse(JsonFormat.Shape.STRING.isStructured());
